"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const docker_1 = require("./docker");
const fs_1 = require("./fs");
const datauri_1 = require("./datauri");
async function cordovaPlatformAdd(ctx, image, platform) {
    await docker_1.prettyUserCommand(ctx, image, ['cordova', 'platform', 'add', platform, '--no-fetch']);
}
exports.cordovaPlatformAdd = cordovaPlatformAdd;
async function cordovaBuildAndroid(ctx, image, { credentials }) {
    const cordovaArgs = ['cordova', 'build', 'android'];
    if (credentials) {
        const keystoreFile = credentials.keystore_file;
        const keystorePassword = credentials.keystore_password;
        const keyAlias = credentials.key_alias;
        const keyPassword = credentials.key_password ? credentials.key_password : credentials.keystore_password;
        const keystore = datauri_1.datauri(keystoreFile).body;
        const keystoreFilename = 'android.keystore';
        const keystorePath = path.resolve(ctx.codedir, keystoreFilename);
        await fs_1.fsWriteFile(keystorePath, keystore);
        if (ctx.env.get('BUILD_TYPE') === 'release') {
            cordovaArgs.push('--release');
        }
        cordovaArgs.push('--');
        cordovaArgs.push(`--keystore=${keystoreFilename}`);
        cordovaArgs.push([`--storePassword=${keystorePassword}`, '--storePassword=*****']);
        cordovaArgs.push(`--alias=${keyAlias}`);
        cordovaArgs.push([`--password=${keyPassword}`, '--password=*****']);
    }
    await docker_1.prettyUserCommand(ctx, image, cordovaArgs);
}
exports.cordovaBuildAndroid = cordovaBuildAndroid;
async function patchGradleRepositories(ctx) {
    // Always put the Google repo above jcenter in Gradle build files
    // https://github.com/apache/cordova-android/pull/450
    // https://github.com/apache/cordova-android/pull/523
    const files = [
        'platforms/android/app/build.gradle',
        'platforms/android/build.gradle',
        'platforms/android/CordovaLib/build.gradle'
    ];
    for (const file of files) {
        try {
            const filePath = path.resolve(ctx.codedir, file);
            const data = await fs_1.fsReadFile(filePath, { encoding: 'utf8' });
            const patchedData = data
                .replace(/^\s*jcenter\(\)\n/gm, '') // delete jcenter()
                .replace(/^(\s*)(maven {\n.*\n\s*})/gm, '$1$2\n$1jcenter()'); // append jcenter() after maven block
            if (patchedData !== data) {
                await fs_1.fsWriteFile(filePath, patchedData, { encoding: 'utf8' });
                ctx.userlog.info(ctx.c.yellow(`Updated repositories in ${file}`));
            }
        }
        catch (e) {
            ctx.userlog.error(ctx.c.red(`Failed to update repositories in ${file}`));
        }
    }
}
exports.patchGradleRepositories = patchGradleRepositories;
